#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 summoner-tui
version:              2.2.0.0
visibility:           public
id:                   summoner-tui-2.2.0.0-H3b3sON597w8u6rh7sdU0n
key:                  summoner-tui-2.2.0.0-H3b3sON597w8u6rh7sdU0n
license:              MPL-2.0
copyright:            2018-2026 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
stability:            experimental
homepage:             https://github.com/kowainik/summoner
synopsis:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects using TUI.

description:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects using TUI.
    See [README.md](https://github.com/kowainik/summoner#-summoner) for details.

category:             TUI, TUI Tool, Development
abi:                  df0c28670f445448bf549bd6da350129
exposed:              True
exposed-modules:
    Summoner.Tui Summoner.Tui.Field Summoner.Tui.Form
    Summoner.Tui.GroupBorder Summoner.Tui.Kit Summoner.Tui.Validation
    Summoner.Tui.Widget

hidden-modules:       Paths_summoner_tui
import-dirs:          /usr/lib/ghc-9.6.6/site-local/summoner-tui-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/summoner-tui-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/summoner-tui-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-summoner-tui
hs-libraries:         HSsummoner-tui-2.2.0.0-H3b3sON597w8u6rh7sdU0n
depends:
    base-4.18.2.1 relude-1.2.2.2-2nl1K8eSyLUArcR7ZxDH2Z
    brick-2.13-71iT2cRixoaEcQM2rk6unE
    colourista-0.1.0.2-8okfGkw2bp72ZZdI1asRDq directory-1.3.8.5
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-th-0.4.3.17-1JCZcjTuCbDB2Q9keDntvT
    summoner-2.2.0.0-K9l2Qq4ntjgHVxOE81wJ6U
    validation-selective-0.2.0.0-9SE9evvT2Hr2Nv8hHodCW9
    vty-6.2-2apiP1ZzahsEA39lGKZw2p
    vty-crossplatform-0.4.0.0-Beia7sWbDSjIPPE9rWOj2t

haddock-interfaces:
    /usr/share/doc/haskell-summoner-tui/html/summoner-tui.haddock

haddock-html:         /usr/share/doc/haskell-summoner-tui/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

